# Celest

The Celest library is designed to provide a simple interface for satellite positional representations and encounter planning.
* ***Documentation:*** https://jaiwillems.github.io/Celest/
* ***Source Code:*** https://github.com/JaiWillems/Celest/tree/main/celest
* ***PyPI:*** https://pypi.org/project/Celest/

## Installation
Celest can be installed through a terminal using the following command:
```terminal
pip install Celest
```

## Upcomming Release
The following release will include:
* Julian date and offset inputs,
* Type annotations,
* Numpy style documentation strings,
* Encounter scheduling function for the encounter class, and
* Faster ECI and ECEF conversions through new multiplication method.
